@@ -1,30 +1,31 @@
 #' Analyse SAR CW-OSL measurements
 #'
 #' The function performs a SAR CW-OSL analysis on an
-#' \code{\linkS4class{RLum.Analysis}} object including growth curve fitting.
+#' [RLum.Analysis-class] object including growth curve fitting.
 #'
 #' The function performs an analysis for a standard SAR protocol measurements
 #' introduced by Murray and Wintle (2000) with CW-OSL curves. For the
-#' calculation of the Lx/Tx value the function \link{calc_OSLLxTxRatio} is
-#' used. For \bold{changing the way the Lx/Tx error is calculated} use the argument
-#' \code{background.count.distribution} and \code{sigmab}, which will be passed to the function
-#' \link{calc_OSLLxTxRatio}.\cr\cr
+#' calculation of the Lx/Tx value the function [calc_OSLLxTxRatio] is
+#' used. For **changing the way the Lx/Tx error is calculated** use the argument
+#' `background.count.distribution` and `sigmab`, which will be passed to the function
+#' [calc_OSLLxTxRatio].
 #'
-#' \bold{Argument \code{object} is of type \code{list}}\cr\cr
+#' **Argument `object` is of type `list`**
 #'
-#' If the argument \code{object} is of type \code{\link{list}} containing \bold{only}
-#' \code{\linkS4class{RLum.Analysis}} objects, the function re-calls itself as often as elements
+#' If the argument `object` is of type [list] containing **only**
+#' [RLum.Analysis-class] objects, the function re-calls itself as often as elements
 #' are in the list. This is usefull if an entire measurement wanted to be analysed without
-#' writing separate for-loops. To gain in full control of the parameters (e.g., \code{dose.points}) for
-#' every aliquot (corresponding to one \code{\linkS4class{RLum.Analysis}} object in the list), in
-#' this case the arguments can be provided as \code{\link{list}}. This \code{list} should
-#' be of similar length as the \code{list} provided with the argument \code{object}, otherwise the function
-#' will create an own list of the requested lenght. Function output will be just one single \code{\linkS4class{RLum.Results}} object.
+#' writing separate for-loops. To gain in full control of the parameters (e.g., `dose.points`) for
+#' every aliquot (corresponding to one [RLum.Analysis-class] object in the list), in
+#' this case the arguments can be provided as [list]. This `list` should
+#' be of similar length as the `list` provided with the argument `object`,
+#' otherwise the function will create an own list of the requested lenght.
+#' Function output will be just one single [RLum.Results-class] object.
 #'
 #' Please be careful when using this option. It may allow a fast an efficient data analysis, but
-#' the function may also break with an unclear error message, due to wrong input data.\cr\cr
+#' the function may also break with an unclear error message, due to wrong input data.
 #'
-#' \bold{Working with IRSL data}\cr\cr
+#' **Working with IRSL data**
 #'
 #' The function was originally designed to work just for 'OSL' curves,
 #' following the principles of the SAR protocol. An IRSL measurement protocol
@@ -33,119 +34,123 @@
 #' however, the function is only capable of analysing curves that follow the
 #' SAR protocol structure, i.e., to analyse a post-IR IRSL protocol, curve data
 #' have to be pre-selected by the user to fit the standards of the SAR
-#' protocol, i.e., Lx,Tx,Lx,Tx and so on. \cr
+#' protocol, i.e., Lx,Tx,Lx,Tx and so on.
 #'
 #' Example: Imagine the measurement contains pIRIR50 and pIRIR225 IRSL curves.
 #' Only one curve type can be analysed at the same time: The pIRIR50 curves or
-#' the pIRIR225 curves.\cr\cr
+#' the pIRIR225 curves.
 #'
-#' \bold{Supported rejection criteria}\cr\cr \sQuote{recycling.ratio}:
-#' calculated for every repeated regeneration dose point.\cr
+#' **Supported rejection criteria**
 #'
-#' \sQuote{recuperation.rate}: recuperation rate calculated by comparing the
+#' `[recycling.ratio]`: calculated for every repeated regeneration dose point.
+#'
+#' `[recuperation.rate]`: recuperation rate calculated by comparing the
 #' Lx/Tx values of the zero regeneration point with the Ln/Tn value (the Lx/Tx
 #' ratio of the natural signal). For methodological background see Aitken and
-#' Smith (1988).\cr
+#' Smith (1988).
 #'
-#' \sQuote{testdose.error}: set the allowed error for the testdose, which per
+#' `[testdose.error]`: set the allowed error for the testdose, which per
 #' default should not exceed 10\%. The testdose error is calculated as Tx_net.error/Tx_net.
 #'
-#' \sQuote{palaeodose.error}: set the allowed error for the De value, which per
+#' `[palaeodose.error]`: set the allowed error for the De value, which per
 #' default should not exceed 10\%.
 #'
-#' @param object \code{\linkS4class{RLum.Analysis}} (\bold{required}): input
-#' object containing data for analysis, alternatively a \code{\link{list}} of
-#' \code{\linkS4class{RLum.Analysis}} objects can be provided.
+#' @param object [RLum.Analysis-class] (**required**):
+#' input object containing data for analysis, alternatively a [list] of
+#' [RLum.Analysis-class] objects can be provided.
 #'
-#' @param signal.integral.min \code{\link{integer}} (\bold{required}): lower
-#' bound of the signal integral. Can be a \code{\link{list}} of \code{\link{integer}s}, if \code{object} is
-#' of type \code{\link{list}}. If the input is vector (e.g., \code{c(1,2)}) the 2nd value will be interpreted
+#' @param signal.integral.min [integer] (**required**):
+#' lower bound of the signal integral. Can be a [list] of [integer]s, if `object` is
+#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
 #' as the minimum signal integral for the Tx curve.
 #'
-#' @param signal.integral.max \code{\link{integer}} (\bold{required}): upper
-#' bound of the signal integral. Can be a \code{\link{list}} of \code{\link{integer}s}, if \code{object} is
-#' of type \code{\link{list}}. If the input is vector (e.g., \code{c(1,2)}) the 2nd value will be interpreted
+#' @param signal.integral.max [integer] (**required**):
+#' upper bound of the signal integral. Can be a [list] of [integer]s, if `object` is
+#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
 #' as the maximum signal integral for the Tx curve.
 #'
-#' @param background.integral.min \code{\link{integer}} (\bold{required}):
-#' lower bound of the background integral. Can be a \code{\link{list}} of \code{\link{integer}s}, if \code{object} is
-#' of type \code{\link{list}}. If the input is vector (e.g., \code{c(1,2)}) the 2nd value will be interpreted
+#' @param background.integral.min [integer] (**required**):
+#' lower bound of the background integral. Can be a [list] of [integer]s, if `object` is
+#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
 #' as the minimum background integral for the Tx curve.
 #'
-#' @param background.integral.max \code{\link{integer}} (\bold{required}):
-#' upper bound of the background integral. Can be a \code{\link{list}} of \code{\link{integer}s}, if \code{object} is
-#' of type \code{\link{list}}. If the input is vector (e.g., \code{c(1,2)}) the 2nd value will be interpreted
+#' @param background.integral.max [integer] (**required**):
+#' upper bound of the background integral. Can be a [list] of [integer]s, if `object` is
+#' of type [list]. If the input is vector (e.g., `c(1,2)`) the 2nd value will be interpreted
 #' as the maximum background integral for the Tx curve.
 #'
-#' @param rejection.criteria \code{\link{list}} (with default): provide a named list
-#' and set rejection criteria in \bold{percentage} for further calculation. Can be a \code{\link{list}} in
-#' a \code{\link{list}}, if \code{object} is of type \code{\link{list}}
+#' @param rejection.criteria [list] (*with default*):
+#' provide a named list and set rejection criteria in **percentage** for further calculation. Can be a [list] in
+#' a [list], if `object` is of type [list]
 #'
-#' Allowed arguments are \code{recycling.ratio}, \code{recuperation.rate},
-#' \code{palaeodose.error}, \code{testdose.error} and \code{exceed.max.regpoint = TRUE/FALSE}.
-#' Example: \code{rejection.criteria = list(recycling.ratio = 10)}.
-#' Per default all numerical values are set to 10, \code{exceed.max.regpoint = TRUE}.
-#' Every criterium can be set to \code{NA}. In this value are calculated, but not considered, i.e.
-#' the RC.Status becomes always \code{'OK'}
+#' Allowed arguments are `recycling.ratio`, `recuperation.rate`,
+#' `palaeodose.error`, `testdose.error` and `exceed.max.regpoint = TRUE/FALSE`.
+#' Example: `rejection.criteria = list(recycling.ratio = 10)`.
+#' Per default all numerical values are set to 10, `exceed.max.regpoint = TRUE`.
+#' Every criterium can be set to `NA`. In this value are calculated, but not considered, i.e.
+#' the RC.Status becomes always `'OK'`
 #'
-#' @param dose.points \code{\link{numeric}} (optional): a numeric vector
-#' containg the dose points values Using this argument overwrites dose point
-#' values in the signal curves. Can be a \code{\link{list}} of \code{\link{numeric}} vectors,
-#' if \code{object} is of type \code{\link{list}}
+#' @param dose.points [numeric] (*optional*):
+#' a numeric vector containg the dose points values Using this argument
+#' overwrites dose point values in the signal curves. Can be a [list] of
+#' [numeric] vectors, if `object` is of type [list]
 #'
-#' @param mtext.outer \code{\link{character}} (optional): option to provide an
-#' outer margin mtext. Can be a \code{\link{list}} of \code{\link{character}s},
-#' if \code{object} is of type \code{\link{list}}
+#' @param mtext.outer [character] (*optional*):
+#' option to provide an outer margin mtext. Can be a [list] of [character]s,
+#' if `object` is of type [list]
 #'
-#' @param plot \code{\link{logical}} (with default): enables or disables plot
-#' output.
+#' @param plot [logical] (*with default*):
+#' enables or disables plot output.
 #'
-#' @param plot.single \code{\link{logical}} (with default) or
-#' \code{\link{numeric}} (optional): single plot output (\code{TRUE/FALSE}) to
-#' allow for plotting the results in single plot windows. If a numerice vector
-#' is provided the plots can be selected individually, i.e. \code{plot.single =
-#' c(1,2,3,4)} will plot the TL and Lx, Tx curves but not the legend (5) or the
+#' @param plot.single [logical] (*with default*) or [numeric] (*optional*):
+#' single plot output (`TRUE/FALSE`) to allow for plotting the results in single plot windows.
+#' If a numerice vector is provided the plots can be selected individually, i.e.
+#' `plot.single = c(1,2,3,4)` will plot the TL and Lx, Tx curves but not the legend (5) or the
 #' growth curve (6), (7) and (8) belong to rejection criteria plots. Requires
-#' \code{plot = TRUE}.
+#' `plot = TRUE`.
 #'
-#' @param \dots further arguments that will be passed to the function
-#' \code{\link{plot_GrowthCurve}} or \code{\link{calc_OSLLxTxRatio}}
-#' (supported: \code{background.count.distribution}, \code{sigmab}, \code{sig0}). \bold{Please note} that
-#' if you consider to use the early light subtraction method you should provide your own \code{sigmab}
-#' value!
+#' @param onlyLxTxTable [logical] (with default): If `TRUE` the dose response curve fitting and plotting
+#' is skipped. This allows to get hands on the Lx/Tx table for large datasets without the need for
+#' a curve fitting.
+#'
+#' @param ... further arguments that will be passed to the function
+#' [plot_GrowthCurve] or [calc_OSLLxTxRatio]
+#' (supported: `background.count.distribution`, `sigmab`, `sig0`).
+#' **Please note** that if you consider to use the early light subtraction
+#'  method you should provide your own `sigmab` value!
 #'
 #'
-#' @return A plot (optional) and an \code{\linkS4class{RLum.Results}} object is
+#' @return
+#' A plot (*optional*) and an [RLum.Results-class] object is
 #' returned containing the following elements:
 #'
-#' \item{data}{\link{data.frame} containing De-values, De-error and
-#' further parameters} \item{LnLxTnTx.values}{\link{data.frame} of all
-#' calculated Lx/Tx values including signal, background counts and the dose
-#' points} \item{rejection.criteria}{\link{data.frame} with values that might
-#' by used as rejection criteria. NA is produced if no R0 dose point exists.}
-#' \item{Formula}{\link{formula} formula that have been used for the growth
-#' curve fitting }\cr The output should be accessed using the function
-#' \code{\link{get_RLum}}.
+#' \item{data}{[data.frame] containing De-values, De-error and further parameters}
+#' \item{LnLxTnTx.values}{[data.frame] of all calculated Lx/Tx values including signal, background counts and the dose points}
+#' \item{rejection.criteria}{[data.frame] with values that might by used as rejection criteria. NA is produced if no R0 dose point exists.}
+#' \item{Formula}{[formula] formula that have been used for the growth curve fitting }
+#'
+#' The output should be accessed using the function [get_RLum].
 #'
 #'
-#' @note This function must not be mixed up with the function
-#' \code{\link{Analyse_SAR.OSLdata}}, which works with
-#' \link{Risoe.BINfileData-class} objects.\cr
+#' @note
+#' This function must not be mixed up with the function
+#' [Analyse_SAR.OSLdata], which works with
+#' [Risoe.BINfileData-class] objects.
 #'
-#' \bold{The function currently does only support 'OSL' or 'IRSL' data!}
+#' **The function currently does only support 'OSL' or 'IRSL' data!**
 #'
-#' @section Function version: 0.7.10
+#' @section Function version: 0.8.3
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France)
+#' @author
+#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
 #'
 #'
-#' @seealso \code{\link{calc_OSLLxTxRatio}}, \code{\link{plot_GrowthCurve}},
-#' \code{\linkS4class{RLum.Analysis}}, \code{\linkS4class{RLum.Results}}
-#' \code{\link{get_RLum}}
+#' @seealso [calc_OSLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
+#' [RLum.Results-class], [get_RLum]
 #'
 #'
-#' @references Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation
+#' @references
+#' Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation
 #' after bleaching. Quaternary Science Reviews 7, 387-393.
 #'
 #' Duller, G., 2003. Distinguishing quartz and feldspar in single grain
@@ -195,6 +200,7 @@
 #' ##show LnTnLxTx table
 #' get_RLum(results, data.object = "LnLxTnTx.table")
 #'
+#' @md
 #' @export
 analyse_SAR.CWOSL<- function(
   object,
@@ -207,6 +213,7 @@ analyse_SAR.CWOSL<- function(
   mtext.outer,
   plot = TRUE,
   plot.single = FALSE,
+  onlyLxTxTable = FALSE,
   ...
 ) {
 
@@ -277,6 +284,7 @@ if(is.list(object)){
                       plot = plot,
                       rejection.criteria = rejection.criteria[[x]],
                       plot.single = plot.single,
+                      onlyLxTxTable = onlyLxTxTable,
                       main = ifelse("main"%in% names(list(...)), list(...)$main, paste0("ALQ #",x)),
                       ...)
 
@@ -759,7 +767,6 @@ if(is.list(object)){
     LnLxTnTx[,"Name"] <- as.character(LnLxTnTx[,"Name"])
 
     # Calculate Recycling Ratio -----------------------------------------------
-
     ##Calculate Recycling Ratio
     if (length(LnLxTnTx[LnLxTnTx[,"Repeated"] == TRUE,"Repeated"]) > 0) {
       ##identify repeated doses
@@ -804,8 +811,6 @@ if(is.list(object)){
 
 
     # Calculate Recuperation Rate ---------------------------------------------
-
-
     ##Recuperation Rate (capable to handle multiple type of recuperation values)
     if (length(LnLxTnTx[LnLxTnTx[,"Name"] == "R0","Name"]) > 0) {
       Recuperation <-
@@ -829,7 +834,6 @@ if(is.list(object)){
 
 
     # Evaluate and Combine Rejection Criteria ---------------------------------
-
     temp.criteria <- c(
       if(!is.null(colnames(RecyclingRatio))){
        colnames(RecyclingRatio)}else{NA},
@@ -1331,6 +1335,7 @@ if(is.list(object)){
 
     # Plotting  GC  ----------------------------------------
 
+    ##create data.frame
     temp.sample <- data.frame(
       Dose = LnLxTnTx$Dose,
       LxTx = LnLxTnTx$LxTx,
@@ -1338,6 +1343,7 @@ if(is.list(object)){
       TnTx = LnLxTnTx$Net_TnTx
     )
 
+
     ##overall plot option selection for plot.single.sel
     if (plot == TRUE && 6 %in% plot.single.sel) {
       plot  <-  TRUE
@@ -1348,119 +1354,160 @@ if(is.list(object)){
     }
 
     ##Fit and plot growth curve
-    temp.GC <- plot_GrowthCurve(temp.sample,
-                                output.plot = plot,
-                                ...)
+    if(!onlyLxTxTable){
+        temp.GC <- plot_GrowthCurve(temp.sample,
+                                    output.plot = plot,
+                                    ...)
 
-    ##grep informaton on the fit object
-    temp.GC.fit.Formula  <- get_RLum(temp.GC, "Formula")
+        ##if null
+        if(is.null(temp.GC)){
+          temp.GC <- data.frame(
+            De = NA,
+            De.Error = NA,
+            D01 = NA,
+            D01.ERROR = NA,
+            D02 = NA,
+            D02.ERROR = NA,
+            De.MC = NA,
+            Fit = NA,
+            RC.Status = NA
+          )
+          temp.GC.fit.Formula <- NA
 
-    ##grep results
-    temp.GC <- get_RLum(temp.GC)
+          ##create empty plots if needed, otherwise subsequent functions may crash
+          if(plot){
+            if("output.plotExtended" %in% list(...) && list(...)$output.plotExtended == FALSE){
+              shape::emptyplot()
 
-    # Provide Rejection Criteria for Palaedose error --------------------------
-    palaeodose.error.calculated <- ifelse(is.na(temp.GC[,1]) == FALSE,
-                                          round(temp.GC[,2] / temp.GC[,1], digits = 5),
-                                          NA)
+            }else{
+              shape::emptyplot()
+              shape::emptyplot()
+              shape::emptyplot()
 
-    palaeodose.error.threshold <-
-      rejection.criteria$palaeodose.error / 100
+            }
 
-    if (is.na(palaeodose.error.calculated)) {
-      palaeodose.error.status <- "FAILED"
+          }
 
-    }else{
-      if(!is.na(palaeodose.error.threshold)){
-        palaeodose.error.status <- ifelse(
-          palaeodose.error.calculated <= palaeodose.error.threshold,
-          "OK", "FAILED"
-        )
-
-
-      }else{
-        palaeodose.error.status <- "OK"
-
-
-      }
-
-    }
-
-    palaeodose.error.data.frame <- data.frame(
-      Criteria = "Palaeodose error",
-      Value = palaeodose.error.calculated,
-      Threshold = palaeodose.error.threshold,
-      Status =  palaeodose.error.status,
-      stringsAsFactors = FALSE
-    )
-
-
-    ##add exceed.max.regpoint
-    if (!is.na(temp.GC[,1]) & !is.na(rejection.criteria$exceed.max.regpoint) && rejection.criteria$exceed.max.regpoint) {
-      status.exceed.max.regpoint <-
-        ifelse(max(LnLxTnTx$Dose) < temp.GC[,1], "FAILED", "OK")
-
-    }else{
-      status.exceed.max.regpoint <- "OK"
-
-    }
-
-    exceed.max.regpoint.data.frame <- data.frame(
-      Criteria = "De > max. dose point",
-      Value = as.numeric(temp.GC[,1]),
-      Threshold = if(is.na(rejection.criteria$exceed.max.regpoint)){
-          NA
-        }else if(!rejection.criteria$exceed.max.regpoint){
-          Inf
         }else{
-          as.numeric(max(LnLxTnTx$Dose))
-        },
-      Status =  status.exceed.max.regpoint
-    )
+
+          ##grep information on the fit object
+          temp.GC.fit.Formula  <- get_RLum(temp.GC, "Formula")
+
+          ##grep results
+          temp.GC <- get_RLum(temp.GC)
+
+          # Provide Rejection Criteria for Palaedose error --------------------------
+          if(is.na(temp.GC[,1])){
+            palaeodose.error.calculated <- NA
+
+          }else{
+            palaeodose.error.calculated <- round(temp.GC[,2] / temp.GC[,1], digits = 5)
+
+          }
+
+          palaeodose.error.threshold <-
+            rejection.criteria$palaeodose.error / 100
+
+          if (is.na(palaeodose.error.calculated)) {
+            palaeodose.error.status <- "FAILED"
+
+          }else{
+            if(!is.na(palaeodose.error.threshold)){
+              palaeodose.error.status <- ifelse(
+                palaeodose.error.calculated <= palaeodose.error.threshold,
+                "OK", "FAILED"
+              )
 
 
-    ##add to RejectionCriteria data.frame
-    RejectionCriteria <- rbind(RejectionCriteria,
-                               palaeodose.error.data.frame,
-                               exceed.max.regpoint.data.frame)
+            }else{
+              palaeodose.error.status <- "OK"
 
 
-    ##add recjection status
-    if (length(grep("FAILED",RejectionCriteria$Status)) > 0) {
-      temp.GC <- data.frame(temp.GC, RC.Status = "FAILED")
+            }
+
+          }
+
+          palaeodose.error.data.frame <- data.frame(
+            Criteria = "Palaeodose error",
+            Value = palaeodose.error.calculated,
+            Threshold = palaeodose.error.threshold,
+            Status =  palaeodose.error.status,
+            stringsAsFactors = FALSE
+          )
 
 
-    }else{
-      temp.GC <- data.frame(temp.GC, RC.Status = "OK")
+          ##add exceed.max.regpoint
+          if (!is.na(temp.GC[,1]) & !is.na(rejection.criteria$exceed.max.regpoint) && rejection.criteria$exceed.max.regpoint) {
+            status.exceed.max.regpoint <-
+              ifelse(max(LnLxTnTx$Dose) < temp.GC[,1], "FAILED", "OK")
+
+          }else{
+            status.exceed.max.regpoint <- "OK"
+
+          }
+
+          exceed.max.regpoint.data.frame <- data.frame(
+            Criteria = "De > max. dose point",
+            Value = as.numeric(temp.GC[,1]),
+            Threshold = if(is.na(rejection.criteria$exceed.max.regpoint)){
+                NA
+              }else if(!rejection.criteria$exceed.max.regpoint){
+                Inf
+              }else{
+                as.numeric(max(LnLxTnTx$Dose))
+              },
+            Status =  status.exceed.max.regpoint
+          )
 
 
-    }
+          ##add to RejectionCriteria data.frame
+          RejectionCriteria <- rbind(RejectionCriteria,
+                                     palaeodose.error.data.frame,
+                                     exceed.max.regpoint.data.frame)
 
 
-    ##add information on the integration limits
-    temp.GC.extened <-
-      data.frame(
-        signal.range = paste(min(signal.integral),":",
-                             max(signal.integral)),
-        background.range = paste(min(background.integral),":",
-                                 max(background.integral)),
-        signal.range.Tx = paste(min(ifelse(is.null(signal.integral.Tx),NA,signal.integral.Tx)),":",
-                                max(ifelse(is.null(signal.integral.Tx),NA,signal.integral.Tx))),
-        background.range.Tx = paste(min(ifelse(is.null(background.integral.Tx), NA,background.integral.Tx)) ,":",
-                                    max(ifelse(is.null(background.integral.Tx), NA,background.integral.Tx))),
-        stringsAsFactors = FALSE
-      )
+        ##add recjection status
+        if (length(grep("FAILED",RejectionCriteria$Status)) > 0) {
+          temp.GC <- data.frame(temp.GC, RC.Status = "FAILED")
 
 
+        }else{
+          temp.GC <- data.frame(temp.GC, RC.Status = "OK")
+
+
+        }
+       }#endif for is.null
+
+     ##end onlyLxTxTable
+     }else{
+       temp.GC <- data.frame(De = NA, De.Error = NA, D01 = NA, D01.ERROR = NA, D02 = NA, D02.ERROR = NA, De.MC = NA, Fit = NA)
+       temp.GC.fit.Formula <- NULL
+     }
+
+      ##add information on the integration limits
+      temp.GC.extended <-
+        data.frame(
+          signal.range = paste(min(signal.integral),":",
+                               max(signal.integral)),
+          background.range = paste(min(background.integral),":",
+                                   max(background.integral)),
+          signal.range.Tx = paste(min(ifelse(is.null(signal.integral.Tx),NA,signal.integral.Tx)),":",
+                                  max(ifelse(is.null(signal.integral.Tx),NA,signal.integral.Tx))),
+          background.range.Tx = paste(min(ifelse(is.null(background.integral.Tx), NA,background.integral.Tx)) ,":",
+                                      max(ifelse(is.null(background.integral.Tx), NA,background.integral.Tx))),
+          stringsAsFactors = FALSE
+        )
+
 
     # Set return Values -----------------------------------------------------------
 
     ##generate unique identifier
-    UID <- .create_UID()
+    UID <- create_UID()
 
     temp.results.final <- set_RLum(
       class = "RLum.Results",
       data = list(
-        data = as.data.frame(c(temp.GC, temp.GC.extened, UID = UID), stringsAsFactors = FALSE),
+        data = as.data.frame(c(temp.GC, temp.GC.extended, UID = UID), stringsAsFactors = FALSE),
         LnLxTnTx.table = cbind(LnLxTnTx, UID = UID, stringsAsFactors = FALSE),
         rejection.criteria = cbind(RejectionCriteria, UID, stringsAsFactors = FALSE),
         Formula = temp.GC.fit.Formula
@@ -1468,7 +1515,6 @@ if(is.list(object)){
       info = list(call = sys.call())
     )
 
-
     # Plot graphical interpretation of rejection criteria -----------------------------------------
 
     if (plot == TRUE && 7 %in% plot.single.sel) {
@@ -1479,7 +1525,6 @@ if(is.list(object)){
         par(mfrow = c(1,1))
       }
 
-
       ##Rejection criteria
       temp.rejection.criteria <- get_RLum(temp.results.final,
                                           data.object = "rejection.criteria")
@@ -1675,9 +1720,21 @@ if(is.list(object)){
     if (plot == TRUE && 8 %in% plot.single.sel) {
       ##graphical represenation of IR-curve
       temp.IRSL <- suppressWarnings(get_RLum(object, recordType = "IRSL"))
-
       if(length(temp.IRSL) != 0){
-        plot_RLum.Data.Curve(temp.IRSL, par.local = FALSE)
+         if(class(temp.IRSL) == "RLum.Data.Curve"){
+           plot_RLum.Data.Curve(temp.IRSL, par.local = FALSE)
+
+         }else if(call(temp.IRSL) == "list"){
+           plot_RLum.Data.Curve(temp.IRSL[[length(temp.IRSL)]], par.local = FALSE)
+           warning(
+             "[analyse_SAR.CWOSL()] Multiple IRSL curves detected (IRSL test), show only the last one.",
+             immediate. = TRUE,
+             call. = FALSE
+           )
+         }else{
+           shape::emptyplot()
+
+         }
 
       }else{
         plot(1, type="n", axes=F, xlab="", ylab="")
