@@ -82,3 +82,19 @@ test_that("check values from output example", {
 
 
 })
+
+test_that("check extrapolation", {
+  testthat::skip_on_cran()
+
+  LxTxData[1,2:3] <- c(0.5, 0.001)
+  LIN <- plot_GrowthCurve(LxTxData,mode = "extrapolation", fit.method = "LIN")
+  EXP <- plot_GrowthCurve(LxTxData,mode = "extrapolation", fit.method = "EXP")
+  EXPLIN <- plot_GrowthCurve(LxTxData,mode = "extrapolation", fit.method = "EXP+LIN")
+
+  expect_equivalent(round(LIN$De$De,0), 165)
+  expect_equivalent(round(EXP$De$De,0),  110)
+  #it fails on some unix platforms for unknown reason.
+  #expect_equivalent(round(EXPLIN$De$De,0), 110)
+
+})
+
